CollectionMode

Enum CollectionMode 

pub enum CollectionMode {
    Collector,
    Listener,
}
CSI collection behavior for the node.

Use Listener to keep CSI traffic flowing without processing packets, or Collector to actively process CSI data. Note: Listener combined with a sniffer node makes the sniffer effectively useless because no CSI data is processed.

Variants



Collector

Enables CSI collection and processes CSI data.



Listener

Enables CSI collection but does not process CSI data.